#!/bin/bash

# Check dependencies
#
if [[ -z "$(/sbin/ldconfig -p | grep libopenal)" ]]; then
	if [[ -n "$(which zenity)" ]]; then
		zenity --error --text="Could not find OpenAL audio library.\n\nPlease install it in order to run this program."
	else
		echo "Could not find OpenAL audio library. Please install it in order to run this program."
	fi
	exit 1
fi

# Application binary name
#
APPLICATION_BINARY_NAME=b-render

# Detect current architecture (32 or 64)
#
SYSTEM_ARCH_BITS=$(getconf LONG_BIT)

# Get current directory
#
CURRENT_DIRECTORY=$(dirname "$BASH_SOURCE")

# Get engine directory
#
ENGINE_DIRECTORY="$CURRENT_DIRECTORY"/data

# Change dynamic linker search path
#
export LD_LIBRARY_PATH="$ENGINE_DIRECTORY":$LD_LIBRARY_PATH

# Change current directory
#
cd "$ENGINE_DIRECTORY"

# Launch executable
#
./"$APPLICATION_BINARY_NAME"_x86_"$SYSTEM_ARCH_BITS".bin
